export const description =
  'On this page, we’ll dive into the different conversation endpoints you can use to manage conversations programmatically.'

Once upon a time in the city of Gotham, there was a powerful superhero named Robyn. Robyn had a unique set of abilities that allowed it to fetch information from the far corners of the internet. It could send requests and receive responses at lightning speed, and its prowess was admired by developers everywhere.

One day, Batman approached Robyn for help with building a web application. Batman had heard about Robyn's powerful features and wanted to harness them to create a remarkable application. Batman was looking for an ally and in Robyn, he found the best one!


## Installing Robyn


Robyn is a Python library that you can install using `pip` or `conda`

  <CodeGroup title="installation">

  ```bash {{ title: 'pip' }}
  pip install robyn
  ```

  ```bash {{ title: 'conda' }}
  conda install robyn -c conda-forge
  ```
  </CodeGroup>

While there are other more extensions of Robyn like

  <CodeGroup title="installation">

  ```bash {{ title: 'pip' }}
  pip install "robyn[templating]"
  ```

  ```bash {{ title: 'conda' }}
  conda install "robyn[templating]" -c conda-forge
  ```
  </CodeGroup>



It is recommended to install the base package first and then install the extensions as needed.

## What's next?

Now, we can start using Robyn to build our application.


- [Getting Started](/documentation/en/api_reference/getting_started)



